@@ -7,6 +7,7 @@
 #' @template args
 #' @template moreargs
 #' @template cursor_args
+#' @template field_queries
 #' @param works (logical) If TRUE, works returned as well, if not then not.
 #' @param facet (logical) Include facet results. Default: \code{FALSE}
 #' @param parse (logical) Whether to output json \code{FALSE} or parse to
@@ -53,13 +54,17 @@
 #'    cursor_max = 300, limit = 100)
 #' cr_members_(member_ids = 98, works = TRUE, cursor = "*",
 #'    cursor_max = 300, limit = 100, parse=TRUE)
+#'    
+#' # field queries
+#' ## query.container-title
+#' cr_members(98, works = TRUE, flq = c(`query.container-title` = 'Ecology'))
 #' }
 `cr_members` <- function(member_ids = NULL, query = NULL, filter = NULL, offset = NULL,
   limit = NULL, sample = NULL, sort = NULL, order = NULL, facet=FALSE, works = FALSE,
-  cursor = NULL, cursor_max = 5000, .progress="none", ...) {
+  cursor = NULL, cursor_max = 5000, .progress="none", flq = NULL, ...) {
 
   args <- prep_args(query, filter, offset, limit, sample, sort, order, 
-                    facet, cursor)
+                    facet, cursor, flq)
   if (length(member_ids) > 1) {
     res <- llply(member_ids, member_GET, args = args, works = works,
                  cursor = cursor, cursor_max = cursor_max, ..., 
@@ -118,10 +123,10 @@
 `cr_members_` <- function(member_ids = NULL, query = NULL, filter = NULL, 
   offset = NULL, limit = NULL, sample = NULL, sort = NULL, order = NULL, 
   facet=FALSE, works = FALSE, cursor = NULL, cursor_max = 5000, 
-  .progress="none", parse=FALSE, ...) {
+  .progress="none", parse=FALSE, flq = NULL, ...) {
 
   args <- prep_args(query, filter, offset, limit, sample, sort, 
-                    order, facet, cursor)
+                    order, facet, cursor, flq)
   if (length(member_ids) > 1) {
     llply(member_ids, member_GET_, args = args, works = works,
           cursor = cursor, cursor_max = cursor_max, parse = parse, 
