@@ -6,6 +6,7 @@
 #' @template args
 #' @template moreargs
 #' @template cursor_args
+#' @template field_queries
 #' @param facet (logical) Include facet results. Default: \code{FALSE}
 #' @param works (logical) If TRUE, works returned as well, if not then not.
 #' @param parse (logical) Whether to output json \code{FALSE} or parse to
@@ -46,15 +47,20 @@
 #'    cursor_max = 300, limit = 100)
 #' cr_types_("journal-article", works = TRUE, cursor = "*",
 #'    cursor_max = 300, limit = 100, parse = TRUE)
+#'    
+#' # field queries
+#' ## query.container-title
+#' cr_types("journal-article", works = TRUE,
+#'   flq = c(`query.container-title` = 'Ecology'))
 #' }
 
 `cr_types` <- function(types = NULL, query = NULL, filter = NULL, 
   offset = NULL, limit = NULL, sample = NULL, sort = NULL, order = NULL, 
   facet = FALSE, works = FALSE, cursor = NULL, cursor_max = 5000, 
-  .progress="none", ...) {
+  .progress="none", flq = NULL, ...) {
 
   args <- prep_args(query, filter, offset, limit, sample, sort, order, 
-                    facet, cursor)
+                    facet, cursor, flq)
   if (length(types) > 1) {
     res <- llply(types, types_GET, args = args, works = works,
                  cursor = cursor, cursor_max = cursor_max, ..., 
@@ -123,10 +129,10 @@
 `cr_types_` <- function(types = NULL, query = NULL, filter = NULL, 
   offset = NULL, limit = NULL, sample = NULL, sort = NULL, order = NULL, 
   facet=FALSE, works = FALSE, cursor = NULL, cursor_max = 5000, 
-  .progress="none", parse=FALSE, ...) {
+  .progress="none", parse=FALSE, flq = NULL, ...) {
 
   args <- prep_args(query, filter, offset, limit, sample, sort, order, 
-                    facet, cursor)
+                    facet, cursor, flq)
   if (length(types) > 1) {
     llply(types, types_GET_, args = args, works = works,
           cursor = cursor, cursor_max = cursor_max, parse = parse, ..., 
