@@ -6,6 +6,7 @@
 #' @template args
 #' @template moreargs
 #' @template cursor_args
+#' @template field_queries
 #' @param facet (logical) Include facet results. Default: \code{FALSE}
 #' @param parse (logical) Whether to output json \code{FALSE} or parse to
 #' list \code{TRUE}. Default: \code{FALSE}
@@ -39,6 +40,10 @@
 #' cr_works(filter=c(has_full_text = TRUE))
 #' # has affilitation data
 #' cr_works(filter=c(has_affiliation = TRUE))
+#' # has abstract
+#' cr_works(filter=c(has_abstract = TRUE))
+#' # has clinical trial number
+#' cr_works(filter=c(has_clinical_trial_number = TRUE))
 #'
 #' # Querying dois
 #' cr_works(dois='10.1063/1.3593378')
@@ -80,17 +85,29 @@
 #' cr_works_(query="NSF", cursor = "*", cursor_max = 300, limit = 100)
 #' cr_works_(query="NSF", cursor = "*", cursor_max = 300, limit = 100, 
 #'    parse=TRUE)
+#'    
+#' # field queries
+#' ## query.author
+#' res <- cr_works(query = "ecology", flq = c(query.author = 'Boettiger'))
+#'
+#' ## query.container-title
+#' res <- cr_works(query = "ecology", 
+#'   flq = c(`query.container-title` = 'Ecology'))
+#' 
+#' ## query.author and query.title
+#' res <- cr_works(query = "ecology", 
+#'   flq = c(query.author = 'Smith', query.title = 'cell'))
 #' }
 
 `cr_works` <- function(dois = NULL, query = NULL, filter = NULL, offset = NULL,
   limit = NULL, sample = NULL, sort = NULL, order = NULL, facet=FALSE,
-  cursor = NULL, cursor_max = 5000, .progress="none", ...) {
+  cursor = NULL, cursor_max = 5000, .progress="none", flq = NULL, ...) {
 
   if (cursor_max != as.integer(cursor_max)) {
     stop("cursor_max must be an integer", call. = FALSE)
   }
   args <- prep_args(query, filter, offset, limit, sample, sort, order, 
-                    facet, cursor)
+                    facet, cursor, flq)
 
   if (length(dois) > 1) {
     res <- llply(dois, cr_get_cursor, args = args, cursor = cursor,
@@ -127,13 +144,13 @@
 #' @rdname cr_works
 `cr_works_` <- function(dois = NULL, query = NULL, filter = NULL, offset = NULL,
   limit = NULL, sample = NULL, sort = NULL, order = NULL, facet=FALSE,
-  cursor = NULL, cursor_max = 5000, .progress="none", parse=FALSE, ...) {
+  cursor = NULL, cursor_max = 5000, .progress="none", parse=FALSE, flq = NULL, ...) {
 
   if (cursor_max != as.integer(cursor_max)) {
     stop("cursor_max must be an integer", call. = FALSE)
   }
   args <- prep_args(query, filter, offset, limit, sample, sort, order, 
-                    facet, cursor)
+                    facet, cursor, flq)
 
   if (length(dois) > 1) {
     llply(dois, cr_get_cursor_, args = args, cursor = cursor,
@@ -198,45 +215,45 @@ parse_works <- function(zzz){
             'deposited','DOI','funder','indexed','ISBN','ISSN','issue',
             'issued','license', 'link','member','page','prefix','publisher',
             'reference-count','score','source', 'subject','subtitle','title',
-            'type','update-policy','URL','volume')
-  manip <- function(which="issued", y){
-    res <- switch(which,
-                  `alternative-id` = list(paste0(unlist(y[[which]]), 
-                                                 collapse = ",")),
-                  `archive` = list(y[[which]]),
-                  `container-title` = list(paste0(unlist(y[[which]]), 
-                                                  collapse = ",")),
-                  created = list(make_date(y[[which]]$`date-parts`)),
-                  deposited = list(make_date(y[[which]]$`date-parts`)),
-                  DOI = list(y[[which]]),
-                  #funder = list(parse_awards(y[[which]])),
-                  indexed = list(make_date(y[[which]]$`date-parts`)),
-                  ISBN = list(paste0(unlist(y[[which]]), collapse = ",")),
-                  ISSN = list(paste0(unlist(y[[which]]), collapse = ",")),
-                  issue = list(y[[which]]),
-                  issued = list(
-                    paste0(
-                      sprintf("%02d", 
-                              unlist(y[[which]]$`date-parts`)), collapse = "-")
-                  ),
-                  license = list(parse_license(y[[which]])),
-                  #link = list(get_links(y[[which]])),
-                  member = list(y[[which]]),
-                  page = list(y[[which]]),
-                  prefix = list(y[[which]]),
-                  publisher = list(y[[which]]),
-                  `reference-count` = list(y[[which]]),
-                  score = list(y[[which]]),
-                  source = list(y[[which]]),
-                  subject = list(paste0(unlist(y[[which]]), collapse = ",")),
-                  subtitle = list(y[[which]]),
-                  title = list(paste0(unlist(y[[which]]), collapse = ",")),
-                  type = list(y[[which]]),
-                  `update-policy` = list(y[[which]]),
-                  URL = list(y[[which]]),
-                  volume = list(y[[which]])
+            'type','update-policy','URL','volume','abstract')
+  manip <- function(which="issued", y) {
+    res <- switch(
+      which,
+      `alternative-id` = list(paste0(unlist(y[[which]]), 
+                                     collapse = ",")),
+      `archive` = list(y[[which]]),
+      `container-title` = list(paste0(unlist(y[[which]]), 
+                                      collapse = ",")),
+      created = list(make_date(y[[which]]$`date-parts`)),
+      deposited = list(make_date(y[[which]]$`date-parts`)),
+      DOI = list(y[[which]]),
+      indexed = list(make_date(y[[which]]$`date-parts`)),
+      ISBN = list(paste0(unlist(y[[which]]), collapse = ",")),
+      ISSN = list(paste0(unlist(y[[which]]), collapse = ",")),
+      issue = list(y[[which]]),
+      issued = list(
+        paste0(
+          sprintf("%02d", 
+                  unlist(y[[which]]$`date-parts`)), collapse = "-")
+      ),
+      license = list(parse_license(y[[which]])),
+      member = list(y[[which]]),
+      page = list(y[[which]]),
+      prefix = list(y[[which]]),
+      publisher = list(y[[which]]),
+      `reference-count` = list(y[[which]]),
+      score = list(y[[which]]),
+      source = list(y[[which]]),
+      subject = list(paste0(unlist(y[[which]]), collapse = ",")),
+      subtitle = list(y[[which]]),
+      title = list(paste0(unlist(y[[which]]), collapse = ",")),
+      type = list(y[[which]]),
+      `update-policy` = list(y[[which]]),
+      URL = list(y[[which]]),
+      volume = list(y[[which]]),
+      abstract = list(y[[which]])
     )
-
+    
     res <- if (is.null(res) || length(res) == 0) NA else res
     if (length(res[[1]]) > 1) {
       names(res[[1]]) <- paste(which, names(res[[1]]), sep = "_")
@@ -254,10 +271,11 @@ parse_works <- function(zzz){
   } else {
     out_tmp <- data.frame(as.list(unlist(lapply(keys, manip, y = zzz))), 
                           stringsAsFactors = FALSE)
-    out_tmp$assertion <- list(parse_todf(zzz$assertion))
-    out_tmp$author <- list(parse_todf(zzz$author))
-    out_tmp$funder <- list(parse_todf(zzz$funder))
-    out_tmp$link <- list(parse_todf(zzz$link))
+    out_tmp$assertion <- list(parse_todf(zzz$assertion)) %||% NULL
+    out_tmp$author <- list(parse_todf(zzz$author)) %||% NULL
+    out_tmp$funder <- list(parse_todf(zzz$funder)) %||% NULL
+    out_tmp$link <- list(parse_todf(zzz$link)) %||% NULL
+    out_tmp$`clinical-trial-number` <- list(parse_todf(zzz$`clinical-trial-number`)) %||% NULL
     return(out_tmp)
   }
 }
@@ -279,6 +297,14 @@ parse_license <- function(x){
   }
 }
 
+parse_ctn <- function(x){
+  if (is.null(x)) {
+    NULL
+  } else {
+    stats::setNames(x[[1]], c('number', 'registry'))
+  }
+}
+
 parse_todf <- function(x){
   if (is.null(x)) {
     NULL
