@@ -4,6 +4,10 @@
 #' @param url A URL.
 #' @param type A document type, one of xml, pdf, or plain
 #' @param doi A DOI, optional, defaults to \code{NULL}
+#' @note This function is deprecated, and will be removed in the next 
+#' version. All text mining functionality will be moved to the new 
+#' package \code{crminer}.
+#' @family textmining
 #' @examples \dontrun{
 #' as.tdmurl("http://downloads.hindawi.com/journals/bmri/2014/201717.xml", 
 #'    "xml")
@@ -17,11 +21,15 @@ as.tdmurl <- function(url, type, doi) UseMethod("as.tdmurl")
 
 #' @export
 #' @rdname as.tdmurl
-as.tdmurl.tdmurl <- function(url, type, doi) url
+as.tdmurl.tdmurl <- function(url, type, doi) {
+  .Deprecated("as_tdmurl", "crminer", "Will be removed in next version")
+  url
+}
 
 #' @export
 #' @rdname as.tdmurl
 as.tdmurl.character <- function(url, type, doi=NULL) {
+  .Deprecated("as_tdmurl", "crminer", "Will be removed in next version")
   makeurl(check_url(url), type, doi)
 }
 
